def add(x, y):
    return x + y

def subtract(x, y):
    return x - y

def multiply(x, y):
    return x * y

def divide(x, y):
    if y != 0:
        return x / y
    else:
        raise ValueError("Cannot divide by zero")



from setuptools import setup, find_packages

setup(
    name='sheljacalci',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        # Add your dependencies here if any
    ],
)